<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/14/2003 *
 * ===================                          Last change: 04/28/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-login.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Login area (redirects to the real login module)  *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Loginbereich (leitet an das richtige Lgin-Modul  *
 *                     weiter)                                          *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} // END - if

// Add description as navigation point
addYouAreHereLink('guest', __FILE__);

if ((!isExtensionActive('user')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=user%}');
	return;
} // END - if

// Initialize variables as not logged in
$errorCode = '0';
$userid = NULL;
$hash = '';
$url = '';
$add = '';

// Already logged in?
if ((isMemberIdSet()) && (isSessionVariableSet('u_hash'))) {
	// Maybe, then continue with it
	$userid = getMemberId();
} elseif ((isPostRequestElementSet('id')) && (isPostRequestElementSet('password')) && (isFormSent('login'))) {
	// Set userid and crypt password when login data was submitted
	if (isNicknameUsed(postRequestElement('id'))) {
		// Nickname entered
		$userid = sqlEscapeString(postRequestElement('id'));
	} else {
		// Direct userid entered
		$userid  = bigintval(postRequestElement('id'));
	}
} elseif (isPostRequestElementSet('new_pass')) {
	// New password requested
	$userid = NULL;
	if (isPostRequestElementSet('email')) {
		// Email is set
		$userid = sqlEscapeString(postRequestElement('email'));
	} elseif (isPostRequestElementSet('id')) {
		// Is there nickname or userid?
		if (isNicknameUsed(postRequestElement('id'))) {
			// Nickname entered
			$userid = sqlEscapeString(postRequestElement('id'));
		} else {
			// Direct userid entered
			$userid  = bigintval(postRequestElement('id'));
		}
	} // END - if
}

if (isMember()) {
	// Login immidiately...
	$url = 'modules.php?module=login';
} elseif ((isFormSent('login')) && ('' . $userid . '' != '' . postRequestElement('id') . '')) {
	// Invalid input (no nickname extension installed but nickname entered)
	$errorCode = getCode('EXTENSION_PROBLEM');
} elseif (isFormSent('login')) {
	// Are both 'id' and 'password' set?
	if ((isPostRequestElementSet('id')) && (isPostRequestElementSet('password'))) {
		// Try the login (see inc/libs/user_functions.php)
		$url = doUserLogin(postRequestElement('id'), postRequestElement('password'));
	} elseif (!isPostRequestElementSet('id')) {
		// Empty 'id'
		$errorCode = getCode('LOGIN_EMPTY_ID');
	} else {
		// Empty 'password'
		$errorCode = getCode('LOGIN_EMPTY_PASSWORD');
	}
} elseif ((isPostRequestElementSet('new_pass')) && (!empty($userid))) {
	// Try the userid/email lookup (see inc/libs/user_functions.php)
	$errorCode = doNewUserPassword(postRequestElement('email'), $userid);
}

// Login problems?
if (isGetRequestElementSet('login')) {
	// Use code from URL
	$errorCode = getRequestElement('login');
} // END  - if

// No problems, no output by detault
$content['message'] = '';

// Login problems?
if (!empty($errorCode)) {
	// Is there a userid set?
	if (isSessionVariableSet('userid')) {
		// Then prefetch data for this account
		fetchUserData(getSession('userid'));
	} // END - if

	// Add message code
	$content['message'] = loadTemplate('guest_login_error_message', TRUE, $errorCode);
} // END - if

// Display login form with resend-password form
if (isExtensionActive('nickname')) {
	loadTemplate('guest_nickname_login', FALSE, $content);
} else {
	loadTemplate('guest_login', FALSE, $content);
}

// Was an URL constructed?
if (!empty($url)) {
	// URL was constructed
	if (ifFatalErrorsDetected()) {
		// Handle fatal errors
		runFilterChain('handle_fatal_errors');
	} else {
		// Load URL
		redirectToUrl($url);
	}
} // END - if

// [EOF]
?>
