<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/16/2003 *
 * ===================                          Last change: 06/30/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-mydata.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Members can edit their profile data here         *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Mitglieder koennen hier ihre Profildaten aendern *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} elseif (!isMember()) {
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

if ((!isExtensionActive('mydata')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=mydata%}');
	return;
} // END - if

// Add userid
$content = array();

// Init variable to prevent notices
$url = '';

// Detect what the member wants to do
$mode = 'show'; // Show his data
if (isFormSent('save'))   $mode = 'save';   // Save entered data
if (isFormSent('edit'))   $mode = 'edit';   // Edit data
if (isFormSent('notify')) $mode = 'notify'; // Switch off notification

switch ($mode) {
	case 'show': // Show his data
		// Get line
		$content = merge_array($content, getUserDataArray());

		// Translate some things
		$content['last_update'] = generateDateTime($content['last_update'], 0);

		// How far is last change on his profile away from now?
		if ((($content['last_update'] + getProfileLock()) > time()) && (!isAdmin()) && (getProfileLock() > 0)) {
			// You cannot change your account
			$content['change'] = displayMessage('<div class="notice">{%message,MEMBER_PROFILE_LOCKED=' . generateDateTime($content['last_update'] + getProfileLock(), 0) . '%}</div>', TRUE);
		} else {
			// He is allowed to change his profile
			$content['change'] = loadTemplate('member_mydata_button', TRUE);
		}

		// @TODO Move this to a function (for better EL code)
		switch (getLanguage()) {
			case 'de': $content['dob'] = '{%pipe,padLeftZero=' . $content['birth_day']   . '%}.{%pipe,padLeftZero=' . $content['birth_month'] . '%}.' . $content['birth_year']; break;
			default  : $content['dob'] = '{%pipe,padLeftZero=' . $content['birth_month'] . '%}-{%pipe,padLeftZero=' . $content['birth_day']   . '%}-' . $content['birth_year']; break;
		} // END - switch

		if (isExtensionActive('country')) {
			// Load country's description and code
			$content['country'] = generateCountryInfo($content['country_code']);
		} // END - if

		// Load template
		loadTemplate('member_mydata_overview', FALSE, $content);
		break;

	case 'edit': // Edit data
		if (isExtensionActive('country', TRUE)) {
			// New way
			$result = sqlQueryEscaped('SELECT
	`surname`,
	`family`,
	`street_nr`,
	`country_code`,
	`zip`,
	`city`,
	`email`,
	`birth_day`,
	`birth_month`,
	`birth_year`,
	`gender`,
	`max_mails`,
	`receive_mails`,
	`last_update`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`userid`=%s
LIMIT 1',
			array(getMemberId()), __FILE__, __LINE__);
		} else {
			// Old way
			$result = sqlQueryEscaped('SELECT
	`surname`,
	`family`,
	`street_nr`,
	`country`,
	`zip`,
	`city`,
	`email`,
	`birth_day`,
	`birth_month`,
	`birth_year`,
	`gender`,
	`max_mails`,
	`receive_mails`,
	`last_update`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`userid`=%s
LIMIT 1',
				array(getMemberId()), __FILE__, __LINE__);
		}

		// Get line
		$content = merge_array($content, sqlFetchArray($result));

		// Free result
		sqlFreeResult($result);

		$content['update_check'] = $content['last_update'] + getProfileLock();

		// How far is last change on his profile away from now?
		if (($content['update_check'] > time()) && (!isAdmin()) && (getProfileLock() > 0)) {
			// Profile is locked, so output propper message
			$content['update_check'] = '{%message,MEMBER_PROFILE_LOCKED=' . generateDateTime($content['update_check'] + getProfileLock(), '0') . '%}';

			// You cannot change your account
			displayMessage($content['update_check']);
		} else {
			// Init elements
			$content['dob'] = '';

			switch (getLanguage()) {
				case 'de': // German date format
					// Day
					$content['dob'] .= addSelectionBox('da', $content['birth_day']);

					// Month
					$content['dob'] .= addSelectionBox('mo', $content['birth_month']);

					// Year
					$content['dob'] .= addSelectionBox('ye', $content['birth_year']);
					break;

				default: // Default is the US date format... :)
					// Month
					$content['dob'] .= addSelectionBox('mo', $content['birth_month']);

					// Day
					$content['dob'] .= addSelectionBox('da', $content['birth_day']);

					// Year
					$content['dob'] .= addSelectionBox('ye', $content['birth_year']);
					break;
			} // END - if

			$content['max_receive_list'] = addMaxReceiveList('member', $content['max_mails']);

			if (isExtensionActive('country')) {
				// Init WHERE statement
				$whereStatement = " WHERE `is_active`='Y'";
				if (isAdmin()) $whereStatement = '';

				// Generate selection box
				$OUT  = '<select name="country_code" class="form_select" size="1">';
				$OUT .= generateOptions('countries', 'id', 'descr', $content['country_code'], 'code', $whereStatement);
				$OUT .= '</select>';
				$content['country'] = $OUT;
			} else {
				// Ouput default input box
				$content['country'] = '<input type="text" name="cntry" class="form_field" size="2" maxlength="3" value="' . $content['country'] . '" />';
			}

			// Load template
			loadTemplate('member_mydata_edit', FALSE, $content);
		}
		break;

	case 'save': // Save entered data
		// Get line
		$content = merge_array($content, getUserDataArray());

		// Calculate time to check
		$content['update_check'] = $content['last_update'] + getProfileLock();

		// How far is last change on his profile away from now?
		if (($content['update_check'] > time()) && (!isAdmin()) && (getProfileLock() > 0)) {
			// You cannot change your account
			$content['update_check'] = generateDateTime($content['update_check'] + getProfileLock(), 0);

			displayMessage($content['update_check']);
		} elseif ((!isEmailValid(postRequestElement('email'))) && (!isAdmin())) {
			// Invalid email address!
			displayMessage('{--INVALID_EMAIL_ENTERED--}');
		} elseif ((isExtensionInstalledAndNewer('other', '0.3.0')) && (isCheckDoubleEmailEnabled()) && (!isAdmin()) && (isEmailTaken(postRequestElement('email')))) {
			// Email address is already registered
			displayMessage('{--MEMBER_EMAIL_IS_ALREADY_REGISTERED--}');
		} else {
			// Generate hash
			$hash = generateHash(postRequestElement('password1'), substr($content['password'], 0, -40));
			if ((($hash == $content['password']) || (postRequestElement('password1') == postRequestElement('password2'))) && (isPostRequestElementSet('password1'))) {
				// Only on simple changes normal mode is active = no email or password changed
				$mode = 'normal';
				$AND = '';

				// Did the user changed the password?
				if ($hash != $content['password']) {
					// Yes
					$AND = ",`password`='" . $hash . "'";
					$mode = 'password';
				} // END - if

				// Or did he changed his email address?
				if (postRequestElement('email') != $content['email']) {
					// Yes, but is it maybe blacklisted?
					$filterData = array(
						'init_done'   => TRUE,
						'post_data'   => postRequestArray(),
						'blacklisted' => '',
						'message'     => '{--PRE_UPDATE_USER_DATA_FAILED--}',
					);
					$filterData = runFilterChain('pre_update_user_data', $filterData);

					// Is it blacklisted?
					if ($filterData['init_done'] === FALSE) {
						// Found something blacklisted
						displayMessage($filterData['message']);
						return;
					} // END - if

					if ($mode == 'normal') {
						$mode = 'email';
					} else {
						$mode .= ';email';
					}
					setPostRequestElement('old_email', $content['email']);
				} // END - if

				// Update member's profile
				if (isExtensionActive('country')) {
					// New way
					sqlQueryEscaped("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`gender`='%s',
	`surname`='%s',
	`family`='%s',
	`street_nr`='%s',
	`country_code`=%s,
	`zip`=%s,
	`city`='%s',
	`email`='%s',
	`birth_day`=%s,
	`birth_month`=%s,
	`birth_year`=%s,
	`max_mails`='%s',
	`last_update`=UNIX_TIMESTAMP()".$AND.",
	`notified`='N',
	`last_profile_sent`=UNIX_TIMESTAMP()
WHERE
	`userid`=%s
LIMIT 1",
						array(
							postRequestElement('gender'),
							postRequestElement('surname'),
							postRequestElement('family'),
							postRequestElement('street_nr'),
							bigintval(postRequestElement('country_code')),
							bigintval(postRequestElement('zip')),
							postRequestElement('city'),
							postRequestElement('email'),
							bigintval(postRequestElement('day')),
							bigintval(postRequestElement('month')),
							bigintval(postRequestElement('year')),
							bigintval(postRequestElement('max_mails')),
							getMemberId()
						), __FILE__, __LINE__);
				} else {
					// Old way
					sqlQueryEscaped("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`gender`='%s',
	`surname`='%s',
	`family`='%s',
	`street_nr`='%s',
	`country`='%s',
	`zip`=%s,
	`city`='%s',
	`email`='%s',
	`birth_day`=%s,
	`birth_month`=%s,
	`birth_year`=%s,
	`max_mails`='%s',
	`last_update`=UNIX_TIMESTAMP()".$AND.",
	`notified`='N',
	`last_profile_sent`=UNIX_TIMESTAMP()
WHERE
	`userid`=%s
LIMIT 1",
						array(
							postRequestElement('gender'),
							postRequestElement('surname'),
							postRequestElement('family'),
							postRequestElement('street_nr'),
							postRequestElement('cntry'),
							bigintval(postRequestElement('zip')),
							postRequestElement('city'),
							postRequestElement('email'),
							bigintval(postRequestElement('day')),
							bigintval(postRequestElement('month')),
							bigintval(postRequestElement('year')),
							bigintval(postRequestElement('max_mails')),
							getMemberId()
						), __FILE__, __LINE__);
				}

				// Did something change?
				if (!ifSqlHasZeroAffectedRows()) {
					// Get all modes ...
					$modes = explode(';', $mode);

					// ... and run them through
					sendModeMails ('mydata', $modes);
				} else {
					// Something went wrong
					displayMessage('{--MEMBER_UPDATE_FAILED--}');
				}
			} else {
				// Entered wrong pass for updating profile
				displayMessage('{--MEMBER_UPDATE_WRONG_PASSWORD--}');
			}
		}
		break;

	case 'notify': // Switch off notfication
		sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `notified`='N',`last_update`=UNIX_TIMESTAMP() WHERE `userid`=%s LIMIT 1",
			array(getMemberId()), __FILE__, __LINE__);
		$url = 'modules.php?module=login&amp;what=mydata&amp;code=' . getCode('PROFILE_UPDATED');
		break;
} // END - switch

if (!empty($url)) {
	// Load generated URL
	redirectToUrl($url);
} // END - if

// [EOF]
?>
