<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/25/2003 *
 * ===================                          Last change: 04/26/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : install.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : Installation script.                             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Installationsscript.                             *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// XDEBUG call
//* DEBUG: */ xdebug_start_trace();

// Load security system
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['__start_time'] = microtime(TRUE);

// Tell every module / require file we are installing
$GLOBALS['__mailer_installing'] = TRUE;

// Set module and output mode
$GLOBALS['__module']      = 'install';
$GLOBALS['__output_mode'] = '0';

// Load config file
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// Is 'install_page' set?
if (!isGetRequestElementSet('install_page')) {
	// No, so set it to 'welcome'
	setGetRequestElement('install_page', 'welcome');
} // END - if

// Set username
setUsername('{--USERNAME_INSTALLER--}');

// Already installed?
if ((isInstalled()) && (getRequestElement('install_page') != 'finished')) {
	// Add fatal message
	addFatalMessage(__FILE__, __LINE__, '{--MAILER_ALREADY_INSTALLED--}');
} // END - if

// Load header here
loadIncludeOnce('inc/header.php');

// Handle fatal errors
runFilterChain('handle_fatal_errors');

// Is plain or AJAX-enabled installation used?
if (isGetRequestElementSet('installer')) {
	// Set installer type
	setSession('installer', getRequestElement('installer'));

	// Redirect to install.php again
	redirectToUrl('install.php');
} elseif (isAjaxInstaller()) {
	// AJAX-enabled installer:
	// Load 'init' page
	addTemplateToInstallContent('install_page_init');

	// Prepare content
	$content = array(
		'install_page' => getRequestElement('install_page')
	);

	// Load main installation table
	loadTemplate('install_main_ajax', FALSE, $content);
} elseif (isPlainInstaller()) {
	// Plain installer:
	// Load include file
	loadIncludeOnce('inc/install-inc.php');

	// Load main template
	loadTemplate('install_main_plain');
} else {
	// What do you want, red or blue pill? AJAX or plain installer? ;-)
	loadTemplate('install_selector');
}

// Footer
loadIncludeOnce('inc/footer.php');

// [EOF]
?>
